'use strict';

var postcss = require('postcss');

var affectedProps = require('./affected-props');

var _require = require('./keyframes'),
    isKeyframeRule = _require.isKeyframeRule,
    isKeyframeAlreadyProcessed = _require.isKeyframeAlreadyProcessed,
    isKeyframeSymmetric = _require.isKeyframeSymmetric,
    rtlifyKeyframe = _require.rtlifyKeyframe;

var _require2 = require('./rules'),
    getDirRule = _require2.getDirRule,
    processSrcRule = _require2.processSrcRule;

var _require3 = require('./decls'),
    rtlifyDecl = _require3.rtlifyDecl,
    ltrifyDecl = _require3.ltrifyDecl;

module.exports = postcss.plugin('postcss-rtl', function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return function (css) {

        // customized function for joining prefix and selector
        var addPrefixToSelector = options.addPrefixToSelector;

        var keyframes = [];

        // collect @keyframes
        css.walkAtRules(function (rule) {
            if (!isKeyframeRule(rule)) return;
            if (isKeyframeAlreadyProcessed(rule)) return;
            if (isKeyframeSymmetric(rule)) return;

            keyframes.push(rule.params);
            rtlifyKeyframe(rule);
        });

        // Simple rules (includes rules inside @media-queries)
        css.walkRules(function (rule) {
            var ltrDecls = [];
            var rtlDecls = [];
            var dirDecls = [];

            if (rule.selector.match(/\[dir/)) return;
            if (isKeyframeRule(rule.parent)) return;

            rule.walkDecls(function (decl) {
                var rtl = rtlifyDecl(decl, keyframes);

                if (rtl) {
                    ltrDecls.push(ltrifyDecl(decl, keyframes));
                    rtlDecls.push(decl.clone(rtl));
                    return;
                }

                if (affectedProps.indexOf(decl.prop) >= 0) {
                    dirDecls.push(decl);
                    decl.remove();
                }
            });

            if (rtlDecls.length) {
                (function () {
                    var ltrDirRule = void 0;
                    getDirRule(rule, 'rtl', addPrefixToSelector).append(rtlDecls);
                    ltrDirRule = getDirRule(rule, 'ltr', addPrefixToSelector);
                    ltrDecls.forEach(function (_decl) {
                        return _decl.moveTo(ltrDirRule);
                    });
                })();
            }

            if (dirDecls.length) {
                getDirRule(rule, 'dir', addPrefixToSelector).append(dirDecls);
            }

            /* set dir attrs */
            processSrcRule(rule);
        });
        return false;
    };
});