'use strict';

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var postcss = require('postcss');
var rtlcss = require('rtlcss');
var unprefixed = postcss.vendor.unprefixed;

var isHtmlSelector = function isHtmlSelector() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/^html/);
};

var isRootSelector = function isRootSelector() {
    var selector = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    return !!selector.match(/:root/);
};

var isKeyframeRule = function isKeyframeRule(rule) {
    return rule.type === 'atrule' && unprefixed(rule.name) === 'keyframes';
};

var getDirRule = function getDirRule(rule, dir) {
    var next = rule.next();
    var selector = addDirToSelectors(rule.selector, dir);

    if (next && next.selector === selector) {
        return next;
    } else {
        return rule.cloneAfter({ selector: selector }).removeAll();
    }
};

var addDirToSelectors = function addDirToSelectors() {
    var selectors = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    var dir = arguments[1];

    var prefix = void 0;

    switch (dir) {
        case 'ltr':
        case 'rtl':
            prefix = '[dir="' + dir + '"]';
            break;
        default:
            prefix = '[dir]';
    }

    selectors = selectors.split(/\s*,\s*/).map(function (selector) {
        if (isHtmlSelector(selector)) {
            selector = selector.replace(/html/ig, 'html' + prefix);
        } else if (isRootSelector(selector)) {
            selector = selector.replace(/:root/ig, prefix + ':root');
        } else {
            selector = 'html' + prefix + ' ' + selector;
        }
        return selector;
    }).join(', ');

    return selectors;
};

var setRuleDir = function setRuleDir(rule, dir) {
    return rule.selector = addDirToSelectors(rule.selector, dir);
};

var rtlifyDecl = function rtlifyDecl(decl) {
    var rtlResult = rtlcss.process(decl, null, null);
    if (rtlResult === decl.toString()) return null;

    var _rtlResult$split = rtlResult.split(/:\s*/),
        _rtlResult$split2 = _slicedToArray(_rtlResult$split, 2),
        prop = _rtlResult$split2[0],
        value = _rtlResult$split2[1];

    return { prop: prop, value: value };
};

var rtlifyRule = function rtlifyRule(rule) {
    var rtlResult = rtlcss.process(rule, null, null);

    return rtlResult !== rule.toString() ? rtlResult : false;
};

module.exports = {
    isHtmlSelector: isHtmlSelector,
    isRootSelector: isRootSelector,
    isKeyframeRule: isKeyframeRule,
    getDirRule: getDirRule,
    setRuleDir: setRuleDir,
    rtlifyDecl: rtlifyDecl,
    rtlifyRule: rtlifyRule
};